@@ -127,6 +127,9 @@ public abstract class Platform {
         /** 64 bit MIPS */
         MIPS64EL,
 
+        /** 64 bit LOONGARCH */
+        LOONGARCH64,
+
         /**
          * Unknown CPU architecture.  A best effort will be made to infer architecture
          * specific values such as address and long size.
@@ -241,6 +244,8 @@ public abstract class Platform {
             return CPU.ARM;
         } else if (equalsIgnoreCase("mips64", archString) || equalsIgnoreCase("mips64el", archString)) {
             return CPU.MIPS64EL;
+        } else if (equalsIgnoreCase("loongarch64", archString)) {
+           return CPU.LOONGARCH64;
         }
 
         // Try to find by lookup up in the CPU list
@@ -302,6 +307,7 @@ public abstract class Platform {
                 case S390X:
                 case AARCH64:
 		case MIPS64EL:
+		case LOONGARCH64:
                     dataModel = 64;
                     break;
                 default:
@@ -371,6 +377,22 @@ public abstract class Platform {
         return addressSize;
     }
 
+    /**
+     * @return true if this platform is 32 bit, else false
+     * Note: do not use this to determine long size, instead use {@link Runtime#longSize()}
+     */
+    public final boolean is32Bit() {
+        return addressSize == 32;
+    }
+
+    /**
+     * @return true if this platform is 64 bit, else false
+     * Note: do not use this to determine long size, instead use {@link Runtime#longSize()}
+     */
+    public final boolean is64Bit() {
+        return addressSize == 64;
+    }
+
     /**
      * Returns true if the current platform is little endian
      * @return true if little endian, false otherwise or if cannot determine
@@ -387,6 +409,15 @@ public abstract class Platform {
         return "big".equals(System.getProperty("sun.cpu.endian"));
     }
 
+    /**
+     * @return the String representing the OS name from the System property {@code os.name} or null if none was found
+     * This is not the same as {@link #getOS()} which returns the {@link OS}.
+     * For example: Mac OS X is the {@link OS#DARWIN} {@link OS} but returns  "Mac OS X" from this method
+     */
+    public final String getOSName() {
+        return System.getProperty("os.name", null);
+    }
+
     /**
      * Gets the name of this <code>Platform</code>.
      *
@@ -396,6 +427,48 @@ public abstract class Platform {
         return cpu + "-" + os;
     }
 
+    /**
+     * Gets the version of this platform as specified by the system property "os.version"
+     * @return the String representing the version of this platform, or null if none could be found
+     */
+    public String getVersion() {
+        return System.getProperty("os.version", null);
+    }
+
+    /**
+     * @return the list of version numbers found from {@link #getVersion()} or an empty list if none were found
+     */
+    private List<String> getVersionNumbers() {
+        String version = getVersion();
+        if (version == null) return Collections.emptyList();
+        Matcher matcher = Pattern.compile("[\\d]+").matcher(version); // get digits only
+        ArrayList<String> result = new ArrayList<>();
+        while (matcher.find()) {
+            result.add(matcher.group());
+        }
+        return result;
+    }
+
+    /**
+     * Gets the number representing the major version of this platform
+     * This uses the first number from {@link #getVersion()}
+     * @return the number representing the major version of this platform or -1 if none was found
+     */
+    public int getVersionMajor() {
+        List<String> versionNumbers = getVersionNumbers();
+        return versionNumbers.size() < 1 ? -1 : Integer.parseInt(versionNumbers.get(0));
+    }
+
+    /**
+     * Gets the number representing the minor version of this platform
+     * This uses the second number from {@link #getVersion()}
+     * @return the number representing the minor version of this platform or -1 if none was found
+     */
+    public int getVersionMinor() {
+        List<String> versionNumbers = getVersionNumbers();
+        return versionNumbers.size() < 2 ? -1 : Integer.parseInt(versionNumbers.get(1));
+    }
+
     /**
      * Returns the platform specific standard C library name
      * 
@@ -788,10 +861,63 @@ public abstract class Platform {
      * A {@link Platform} subclass representing the Windows system.
      */
     private static class Windows extends Supported {
-
         public Windows() {
             super(OS.WINDOWS);
         }
+
+        // This list only includes the Windows versions supported by Java 8+ (our minimum JDK)
+        private static final String WINDOWS_SERVER = "server";
+        private static final String WINDOWS_VISTA = "windows vista";
+        private static final String WINDOWS_7 = "windows 7";
+        private static final String WINDOWS_8 = "windows 8";
+        private static final String WINDOWS_10 = "windows 10";
+        private static final String WINDOWS_11 = "windows 11";
+
+        private String osName() {
+            return System.getProperty("os.name").toLowerCase();
+        }
+
+        /**
+         * @return true if this Windows version is a Windows server version
+         */
+        public boolean isServer() {
+            return osName().contains(WINDOWS_SERVER);
+        }
+
+        /**
+         * @return true if this Windows version is Windows Vista
+         */
+        public boolean isVista() {
+            return osName().contains(WINDOWS_VISTA);
+        }
+
+        /**
+         * @return true if this Windows version is Windows 7
+         */
+        public boolean is7() {
+            return osName().contains(WINDOWS_7);
+        }
+
+        /**
+         * @return true if this Windows version is Windows 8 (or 8.1)
+         */
+        public boolean is8() {
+            return osName().contains(WINDOWS_8);
+        }
+
+        /**
+         * @return true if this Windows version is Windows 10
+         */
+        public boolean is10() {
+            return osName().contains(WINDOWS_10);
+        }
+
+        /**
+         * @return true if this Windows versions is Windows 11
+         */
+        public boolean is11() {
+            return osName().contains(WINDOWS_11);
+        }
     }
 
     private static boolean startsWithIgnoreCase(String s1, String s2) {
